@@ -1,7 +1,6 @@
 OC.L10N.register(
     "circles",
     {
-    "Teams" : "Zespoły",
     "You created the team {circle}" : "Utworzyłeś zespół {circle}",
     "{author} created the team {circle}" : "{author} utworzył zespół {circle}",
     "You deleted {circle}" : "Usunąłeś {circle}",
@@ -52,6 +51,7 @@ OC.L10N.register(
     "{member} sent a request to join {circle}" : "{member} wysłał prośbę o dołączenie do kręgu {circle}",
     "You are the new owner of {circle}" : "Jesteś nowym właścicielem {circle}",
     "{member} is the new owner of {circle}" : "{member} został nowym właścicielem {circle}",
+    "Teams" : "Zespoły",
     "On events happening in a <strong>team</strong> of which you are a member" : "O wydarzeniach w <strong>zespole</strong>, którego jesteś członkiem",
     "Any important event in a <strong>team</strong> you are moderating" : "Każde ważne wydarzenie w <strong>zespole</strong>, który moderujesz",
     "On global events happening in any <strong>team</strong>" : "O wydarzeniach globalnych w dowolnym <strong>zespole</strong>",
@@ -78,6 +78,8 @@ OC.L10N.register(
     "Contact" : "Kontakt",
     "Team" : "Zespół",
     "Nextcloud App" : "Aplikacja Nextcloud",
+    "Teams App" : "Aplikacja Teams",
+    "Admin Command Line" : "Administracyjny wiersz poleceń",
     "Member" : "Członek",
     "Moderator" : "Moderator",
     "Admin" : "Administrator",
@@ -104,12 +106,10 @@ OC.L10N.register(
     "Circles App Initialization" : "Inicjalizacja aplikacji Zespołów",
     "Fresh installation status" : "Stan nowej instalacji",
     "Building Local Database" : "Tworzenie lokalnej bazy danych",
-    "Testing Basic Circle Creation" : "Testowanie tworzenia podstawowego zespołu",
     "Adding local users and moderators" : "Dodawanie lokalnych użytkowników i moderatorów",
     "Show all teams" : "Pokaż wszystkie zespoły",
     "Create a new team" : "Utwórz nowy zespół",
     "Files" : "Pliki",
-    "This feature is not available for personal circles" : "Ta funkcja nie jest dostępna dla kręgów osobistych",
     "The team is not federated" : "Zespół nie jest sfederowany",
     "You cannot join this team" : "Nie możesz dołączyć do tego zespołu",
     "This member is not a moderator" : "Ten członek nie jest moderatorem",
@@ -117,10 +117,6 @@ OC.L10N.register(
     "This member does not exist" : "Ten członek nie istnieje",
     "This member is the owner of the team" : "Ten członek jest właścicielem zespołu",
     "Level cannot be changed for this type of member" : "Nie można zmienić poziomu dla tego typu członka",
-    "You are already a member of this circle" : "Już jesteś członkiem tego kręgu",
-    "You have been blocked from this circle" : "Zostałeś zablokowany w tym zespole",
-    "The account is already a member of this circle" : "Konto jest już członkiem tego zespołu",
-    "The account has already been invited into this circle" : "Konto zostało już zaproszone do tego zespołu",
     "%s (Team owned by %s)" : "%s (Zespół należący do %s)",
     "You are now a member of the Team \"%2$s\"" : "Jesteś teraz członkiem zespołu „%2$s”",
     "You have been invited by %1$s into the Team \"%2$s\"" : "Zostałeś zaproszony przez %1$s do zespołu „%2$s”",
@@ -156,11 +152,6 @@ OC.L10N.register(
     "Name" : "Nazwa",
     "Size" : "Rozmiar",
     "Modified" : "Zmodyfikowano",
-    "Teams' files" : "Pliki zespołów",
-    "Select team to filter by" : "Wybierz zespół, według którego chcesz filtrować",
-    "Please select teams to filter by" : "Wybierz zespoły, według których chcesz filtrować",
-    "No files found for the selected teams" : "Nie znaleziono plików dla wybranych zespołów",
-    "Shared to Circles" : "Udostępnione dla zespołów",
-    "Circle" : "Krąg"
+    "Shared to Circles" : "Udostępnione dla zespołów"
 },
 "nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
