@@ -234,8 +234,8 @@ OC.L10N.register(
     "Could not rename part file to final file, canceled by hook" : "無法將部份檔案重新命名為最終檔案，被掛勾取消",
     "Could not rename part file to final file" : "無法將部份檔案重新命名為最終檔案",
     "Failed to check file size: %1$s" : "檢查檔案大小失敗：%1$s",
-    "Could not open file: %1$s (%2$d), file does seem to exist" : "無法開啟檔案：%1$s（%2$d），檔案似乎存在",
-    "Could not open file: %1$s (%2$d), file doesn't seem to exist" : "無法開啟檔案：%1$s（%2$d），檔案似乎不存在",
+    "Could not open file: %1$s, file does seem to exist" : "無法開啟檔案：%1$s，檔案似乎存在",
+    "Could not open file: %1$s, file doesn't seem to exist" : "無法開啟檔案：%1$s，檔案似乎不存在",
     "Encryption not ready: %1$s" : "尚未準備好加密：%1$s",
     "Failed to open file: %1$s" : "開啟檔案失敗：%1$s",
     "Failed to unlink: %1$s" : "解除連結失敗：%1$s",
@@ -367,8 +367,6 @@ OC.L10N.register(
     "_In a week on %1$s then on %2$s and %3$s_::_In %n weeks on %1$s then on %2$s and %3$s_" : ["將在 %n 星期之後於 %1$s 進行，然後在 %2$s 及 %3$s再次進行"],
     "_In a month on %1$s then on %2$s and %3$s_::_In %n months on %1$s then on %2$s and %3$s_" : ["將在 %n 個月之後於 %1$s 進行，然後在 %2$s 及 %3$s再次進行"],
     "_In a year on %1$s then on %2$s and %3$s_::_In %n years on %1$s then on %2$s and %3$s_" : ["將在 %n 年之後於 %1$s 進行，然後在 %2$s 及 %3$s再次進行"],
-    "Could not open file: %1$s, file does seem to exist" : "無法開啟檔案：%1$s，檔案似乎存在",
-    "Could not open file: %1$s, file doesn't seem to exist" : "無法開啟檔案：%1$s，檔案似乎不存在",
     "No results." : "沒有結果。",
     "Start typing." : "開始輸入。",
     "Time zone:" : "時區："
