@@ -23,38 +23,54 @@ OC.L10N.register(
     "Sharing" : "Megosztás",
     "Federated file sharing" : "Föderált fájlmegosztás",
     "Provide federated file sharing across servers" : "Föderált fájlmegosztás biztosítása a kiszolgálók között",
+    "Confirm data upload to lookup server" : "Keresési kiszolgálóra történő adatfeltöltés megerősítése",
+    "When enabled, all account properties (e.g. email address) with scope visibility set to \"published\", will be automatically synced and transmitted to an external system and made available in a public, global address book." : "Ha engedélyezve van, az összes „közzétett” láthatóságú fióktulajdonság (például e-mail-cím) automatikusan szinkronizálva lesz és átküldésre kerül egy nyilvános, globális címjegyzékbe.",
+    "Disable upload" : "Feltöltés letiltása",
+    "Enable data upload" : "Adatfeltöltés engedélyezése",
+    "Confirm querying lookup server" : "Keresési kiszolgálóról való lekérés megerősítése",
+    "When enabled, the search input when creating shares will be sent to an external system that provides a public and global address book." : "Ha engedélyezve van, a keresési bemenet el lesz küldve egy külső rendszernek, amely egy nyilvános és globális címjegyzéket biztosít.",
+    "This is used to retrieve the federated cloud ID to make federated sharing easier." : "Ez arra használatos, hogy lekérje a föderált felhőazonosítót, hogy megkönnyítse a föderált megosztást.",
+    "Moreover, email addresses of users might be sent to that system in order to verify them." : "Továbbá a felhasználók e-mail-címe is elküldésre kerülhet ellenőrzés céljából.",
+    "Disable querying" : "Lekérdezés letiltása",
+    "Enable querying" : "Lekérdezés engedélyezése",
     "Unable to update federated files sharing config" : "A föderált fájlmegosztási konfiguráció nem frissíthető",
     "Adjust how people can share between servers. This includes shares between people on this server as well if they are using federated sharing." : "Beállítás, hogy az emberek hogyan oszthatnak meg kiszolgálók között. Ebbe beleértendők a kiszolgálón lévő emberek közti megosztások és a  megosztások is.",
     "Allow people on this server to send shares to other servers (this option also allows WebDAV access to public shares)" : "Engedélyezés a kiszolgálón lévő embereknek, hogy megosztásokat küldjenek más kiszolgálóknak (ez a lehetőség lehetővé teszi a nyilvános megosztások WebDAV hozzáférését is)",
     "Allow people on this server to receive shares from other servers" : "Engedélyezés a kiszolgálón lévő embereknek, hogy megosztásokat fogadjanak más kiszolgálóktól",
     "Allow people on this server to send shares to groups on other servers" : "Engedélyezés a kiszolgálón lévő embereknek, hogy megosztásokat küldjenek más kiszolgálók csoportjainak",
     "Allow people on this server to receive group shares from other servers" : "Engedélyezés a kiszolgálón lévő embereknek, hogy csoportmegosztásokat fogadjanak más kiszolgálóktól",
+    "The lookup server is only available for global scale." : "Ez a szolgáltatás csak globális körben érhető el",
     "Search global and public address book for people" : "Emberek keresése a globális és a nyilvános címjegyzékben",
     "Allow people to publish their data to a global and public address book" : "Engedélyezés az emberek számára, hogy közzétegyék az adataikat a globális és nyilvános címjegyzékben",
     "Trusted federation" : "Megbízható föderáció",
     "Automatically accept shares from trusted federated accounts and groups by default" : "A megbízható föderált fiókokból és csoportokból származó megosztások automatikus elfogadása alapértelmezés szerint",
     "Share with me through my #Nextcloud Federated Cloud ID, see {url}" : "Ossza meg velem a #Nextcloud föderált felhőazonosítóm segítségével, lásd {url}",
     "Share with me through my #Nextcloud Federated Cloud ID" : "Ossza meg velem a #Nextcloud föderált felhőazonosítóm segítségével ",
-    "Cloud ID copied to the clipboard" : "Felhőazonosító a vágólapra másolva",
-    "Copy to clipboard" : "Másolás a vágólapra",
+    "Share with me via Nextcloud" : "Ossza meg velem a Nextcloudon keresztül",
+    "Cloud ID copied" : "Felhőazonosító másolva",
+    "Copy" : "Másolás",
     "Clipboard not available. Please copy the cloud ID manually." : "A vágólap nem érhető el. Másolja át a felhőazonosítót kézileg.",
     "Copied!" : "Másolva!",
     "Federated Cloud" : "Föderált felhő",
-    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Bármelyik Nextcloud-kiszolgálót vagy egyéb Open Cloud Mesh-kompatibilis (OCM) kiszolgálót és szolgáltatást használó felhasználóval megoszthatja adatait. Csak tegye a föderált felhőazonosítóját a megosztási párbeszédablakba. Hasonlóan néz ki: person@cloud.example.com",
+    "You can share with anyone who uses a {productName} server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Bármelyik {productName}-kiszolgálót vagy egyéb Open Cloud Mesh-kompatibilis (OCM) kiszolgálót és szolgáltatást használó felhasználóval megoszthatja adatait. Csak írja a föderált felhőazonosítóját a megosztási párbeszédablakba. Hasonlóan néz ki: person@cloud.example.com",
     "Your Federated Cloud ID" : "Az Ön föderált felhőazonosítója",
     "Share it so your friends can share files with you:" : "Ossza meg, hogy a barátai is oszthassanak meg Önnel fájlokat:",
     "Facebook" : "Facebook",
     "X (formerly Twitter)" : "X (korábban Twitter)",
     "formerly Twitter" : "korábban Twitter",
     "Mastodon" : "Mastodon",
+    "Bluesky" : "Bluesky",
     "Add to your website" : "Adja hozzá saját weboldalához",
-    "Share with me via Nextcloud" : "Ossza meg velem a Nextcloudon keresztül",
+    "Share with me via {productName}" : "Megnyitás {productName} használatával",
     "HTML Code:" : "HTML-kód:",
     "Cancel" : "Mégse",
     "Add remote share" : "Távoli megosztás hozzáadása",
     "Remote share" : "Távoli megosztás",
     "Do you want to add the remote share {name} from {owner}@{remote}?" : "Hozzáadja a(z) {name} távoli megosztást innen: {owner}@{remote}?",
     "Remote share password" : "Jelszó a távoli megosztáshoz",
-    "Incoming share could not be processed" : "A bejövő megosztás nem dolgozható fel"
+    "Incoming share could not be processed" : "A bejövő megosztás nem dolgozható fel",
+    "Cloud ID copied to the clipboard" : "Felhőazonosító a vágólapra másolva",
+    "Copy to clipboard" : "Másolás a vágólapra",
+    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Bármelyik Nextcloud-kiszolgálót vagy egyéb Open Cloud Mesh-kompatibilis (OCM) kiszolgálót és szolgáltatást használó felhasználóval megoszthatja adatait. Csak tegye a föderált felhőazonosítóját a megosztási párbeszédablakba. Hasonlóan néz ki: person@cloud.example.com"
 },
 "nplurals=2; plural=(n != 1);");
