@@ -7,28 +7,38 @@
 namespace OCA\Settings\Settings\Admin;
 
 use OCP\AppFramework\Http\TemplateResponse;
+use OCP\AppFramework\Services\IInitialState;
 use OCP\IConfig;
 use OCP\IL10N;
+use OCP\IURLGenerator;
+use OCP\ServerVersion;
 use OCP\Settings\IDelegatedSettings;
+use OCP\Util;
 
 class Overview implements IDelegatedSettings {
-	/** @var IConfig */
-	private $config;
-
-	/** @var IL10N $l */
-	private $l;
-
-	public function __construct(IConfig $config, IL10N $l) {
-		$this->config = $config;
-		$this->l = $l;
+	public function __construct(
+		private ServerVersion $serverVersion,
+		private IConfig $config,
+		private IL10N $l,
+		private IInitialState $initialState,
+		private IURLGenerator $urlGenerator,
+	) {
 	}
 
 	/**
 	 * @return TemplateResponse
 	 */
 	public function getForm() {
+		Util::addScript('settings', 'vue-settings-admin-overview');
+		$this->initialState->provideInitialState('setup-checks-section', [
+			'sectionDocsUrl' => $this->urlGenerator->linkToDocs('admin-warnings'),
+			'installationGuidesDocsUrl' => $this->urlGenerator->linkToDocs('admin-install'),
+			'loggingSectionUrl' => $this->urlGenerator->linkToRoute('settings.AdminSettings.index', ['section' => 'logging']),
+		]);
+
 		$parameters = [
 			'checkForWorkingWellKnownSetup' => $this->config->getSystemValue('check_for_working_wellknown_setup', true),
+			'version' => $this->serverVersion->getHumanVersion(),
 		];
 
 		return new TemplateResponse('settings', 'settings/admin/overview', $parameters, '');
@@ -53,7 +63,7 @@ class Overview implements IDelegatedSettings {
 	}
 
 	public function getName(): ?string {
-		return $this->l->t('Security & setup warnings');
+		return $this->l->t('Security & setup checks');
 	}
 
 	public function getAuthorizedAppConfig(): array {
