@@ -6,15 +6,26 @@ OC.L10N.register(
     "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your Nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "Zeige deine letzten Urlaubsfotos und -videos wie im Film, gib einen Einblick in deinen neuesten Roman direkt aus deiner Nextcloud, wähle die besten GIF-Dateien aus deiner Sammlung dank der direkten Voransicht deiner favorisierten Dateien und viel mehr!",
     "Your browser does not support audio." : "Dein Browser unterstützt kein Audio.",
     "Error loading {name}" : "Fehler beim Laden von {name}",
+    "You are about to overwrite the original file. Are you sure you want to continue?" : "Du bist dabei, die Originaldatei zu überschreiben. Fortfahren?",
+    "A file with this name already exists. Do you want to overwrite it?" : "Eine Datei mit diesem Namen existiert bereits. Soll diese überschrieben werden?",
+    "Confirm overwrite" : "Überschreiben bestätigen",
+    "Cancel" : "Abbrechen",
+    "Overwrite" : "Überschreiben",
+    "An error occurred while trying to confirm the file overwrite." : "Es ist ein Fehler beim Versuch, das Überschreiben der Datei zu bestätigen, aufgetreten.",
     "Image saved" : "Bild gespeichert",
-    "Unsaved changes" : "Ungespeicherte Änderungen",
-    "Drop changes" : "Änderungen löschen",
+    "Error saving image" : "Fehler beim Speichern des Bildes",
+    "Play the live photo" : "Live-Foto abspielen",
+    "LIVE" : "LIVE",
     "Your browser does not support videos." : "Dein Browser unterstützt keine Videos.",
+    "This file no longer exists" : "Diese Datei existiert nicht mehr.",
+    "There is no plugin available to display this file type" : "Es ist kein Plugin zum Anzeigen dieses Dateityps verfügbar",
+    "Failed to save file before download" : "Datei konnte vor dem Herunterladen nicht gespeichert werden",
     "Edit" : "Bearbeiten",
+    "Exit full screen" : "Vollbild verlassen",
+    "Full screen" : "Vollbild",
     "Open sidebar" : "Seitenleiste öffnen",
     "Download" : "Herunterladen",
     "Delete" : "Löschen",
-    "There is no plugin available to display this file type" : "Es ist kein Plugin zum Anzeigen dieses Dateityps verfügbar",
     "View" : "Ansicht",
     "Name" : "Name",
     "Save" : "Speichern",
@@ -23,9 +34,11 @@ OC.L10N.register(
     "Loading …" : "Lade …",
     "Reset" : "Zurücksetzen",
     "All changes will be lost." : "Alle Änderungen gehen verloren.",
-    "Are you sure you want to continue?" : "Bist du dir sicher, dass du fortsetzen möchtest?",
-    "Cancel" : "Abbrechen",
-    "Continue" : "Fortsetzen",
+    "Are you sure you want to continue?" : "Möchtest du fortsetzen?",
+    "Apply" : "Anwenden",
+    "Warning" : "Warnung",
+    "Confirm" : "Bestätigen",
+    "Discard changes" : "Änderungen verwerfen",
     "Undo" : "Rückgängig",
     "Redo" : "Wiederherstellen",
     "Show original image" : "Originalbild anzeigen",
@@ -38,6 +51,7 @@ OC.L10N.register(
     "Watermark" : "Wasserzeichen",
     "Draw" : "Zeichnen",
     "Resize" : "Größe ändern",
+    "Image name" : "BIldname",
     "Invalid image." : "Ungültiges Bild",
     "Error while uploading the image." : "Fehler beim Hochladen des Bildes.",
     "are not images" : "Sind keine Bilder",
@@ -67,6 +81,8 @@ OC.L10N.register(
     "Image" : "Bild",
     "Importing …" : "Importiere …",
     "+ Add image" : "+ Bild hinzufügen",
+    "Upload image" : "Bild hochladen",
+    "From gallery" : "Von der Galerie",
     "Line" : "Linie",
     "Pen" : "Stift",
     "Polygon" : "Polygon",
@@ -75,7 +91,7 @@ OC.L10N.register(
     "Corner Radius" : "Eckenradius",
     "Width in pixels" : "Breite in Pixel",
     "Height in pixels" : "Höhe in Pixel",
-    "Toggle ratio lock" : "Verhältnis-Sperre umschalten",
+    "Toggle ratio lock" : "Seitenverhältnis-Sperre umschalten",
     "Reset to original image size" : "Auf ursprüngliche Bildgröße zurücksetzen",
     "Rotate" : "Rotieren",
     "Text" : "Text",
@@ -87,24 +103,33 @@ OC.L10N.register(
     "Line height" : "Zeilenhöhe",
     "Warmth" : "Wärme",
     "+ Add watermark" : "+ Wasserzeichen hinzufügen",
+    "+ Add text watermark" : "+ Text-Wasserzeichen hinzufügen",
     "Choose watermark type" : "Typ des Wasserzeichens auswählen",
     "Upload watermark" : "Wasserzeichenhochladen",
-    "Add as text" : "AlsTexthinzufügen",
+    "Add as text" : "Als Text hinzufügen",
     "Padding" : "Auffüllen",
+    "Paddings" : "Auffüllungen",
     "Shadow" : "Schatten",
     "Horizontal" : "Horizontal",
     "Vertical" : "Vertikal",
     "Opacity" : "Deckkraft",
+    "Transparency" : "Transparenz",
     "Position" : "Position",
     "Stroke" : "Strich",
     "Save image as" : "Bild speichern unter",
     "Extension" : "Erweiterung",
+    "Format" : "Format",
     "Name is required." : "Name ist erforderlich.",
     "Quality" : "Qualität",
     "Saved image size (width x height)" : "Gespeicherte Bildgröße (Breite x Höhe)",
     "Note that the selected crop area is lower than the applied resize which might cause quality decrease" : "Beachte, dass der ausgewählte Zuschneidebereich kleiner ist als die angewendete Größenänderung, was zu Qualitätseinbußen führen kann.",
     "Actual size (100%)" : "Tatsächliche Größe (100%)",
     "Fit size" : "Größe anpassen",
-    "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "Zeige deine letzten Urlaubsfotos und -videos wie im Film, gib einen Einblick in deinen neuesten Roman direkt aus deiner Nextcloud, wähle die besten GIF-Dateien aus deiner Sammlung dank der direkten Voransicht deiner favorisierten Dateien und viel mehr!"
+    "Select image to add …" : "Bild zum Hinzufügen auswählen …",
+    "Failed to load image." : "Bild konnte nicht geladen werden",
+    "Menu" : "Menü",
+    "Width" : "Breite",
+    "Height" : "Größe",
+    "No preview available for this crop item" : "Für diesen Zuschnitt ist keine Vorschau verfügbar"
 },
 "nplurals=2; plural=(n != 1);");
