@@ -49,6 +49,7 @@ OC.L10N.register(
     "No translation provider available" : "No hay proveedores de traducción disponibles",
     "Could not detect language" : "No fue posible detectar el lenguaje",
     "Unable to translate" : "No es posible traducir",
+    "No valid filters provided" : "No se proporcionaron filtros válidos",
     "[%d / %d]: %s" : "[%d / %d]: %s",
     "Repair step:" : "Paso de reparación:",
     "Repair info:" : "Información de reparación:",
@@ -196,14 +197,6 @@ OC.L10N.register(
     "Matroska video" : "Vídeo Matroska",
     "Windows Media video" : "Vídeo de Windows Media",
     "AVI video" : "Vídeo AVI",
-    "unknown text" : "texto desconocido",
-    "Hello world!" : "¡Hola, mundo!",
-    "sunny" : "soleado",
-    "Hello {name}, the weather is {weather}" : "Hola {name}, el día es {weather}",
-    "Hello {name}" : "Hola {name}",
-    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Estos son sus resultados de búsqueda<script>alert(1)</script></strong>",
-    "new" : "Nuevo",
-    "_download %n file_::_download %n files_" : ["descargar %n archivos","descargar %n archivos","descargar %n archivos"],
     "The update is in progress, leaving this page might interrupt the process in some environments." : "La actualización está en curso, salir de esta página podrían interrumpir el proceso en algunos entornos.",
     "Update to {version}" : "Actualice a {version}",
     "An error occurred." : "Ocurrió un error.",
@@ -233,8 +226,9 @@ OC.L10N.register(
     "Search in current app" : "Buscar en la app actual",
     "Clear search" : "Limpiar búsqueda",
     "Search everywhere" : "Buscar en todas partes",
-    "Searching …" : "Buscando  …",
+    "Searching …" : "Buscando …",
     "Start typing to search" : "Empieza a escribir para buscar",
+    "Minimum search length is {minSearchLength} characters" : "El tamaño mínimo para búsquedas es de {minSearchLength} caracteres",
     "No matching results" : "No hay coincidencias",
     "Today" : "Hoy",
     "Last 7 days" : "Últimos 7 días",
@@ -254,7 +248,7 @@ OC.L10N.register(
     "Load more results" : "Cargar más resultados",
     "Search in" : "Buscar en",
     "Log in" : "Iniciar sesión",
-    "Logging in …" : "Iniciando sesión ...",
+    "Logging in …" : "Iniciando sesión …",
     "Log in to {productName}" : "Iniciar sesión en {productName}",
     "Wrong login or password." : "Nombre de usuario o contraseña incorrecto.",
     "This account is disabled" : "Esta cuenta está deshabilitada",
@@ -291,21 +285,28 @@ OC.L10N.register(
     "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Documentos colaborativos, hojas de cálculo y presentaciones, basadas en Collabora Online.",
     "Distraction free note taking app." : "App de de notas y escritura libre de distracciones.",
     "Recommended apps" : "Aplicaciones recomendadas",
-    "Loading apps …" : "Cargando apps ...",
+    "Loading apps …" : "Cargando apps …",
     "Could not fetch list of apps from the App Store." : "No es posible obtener la lista de apps de la App Store.",
     "App download or installation failed" : "Falló la descarga o instalación de la App",
     "Cannot install this app because it is not compatible" : "No se puede instalar esta app porque no es compatible.",
     "Cannot install this app" : "No se puede instalar esta app",
     "Skip" : "Saltar",
-    "Installing apps …" : "Instalando apps ...",
+    "Installing apps …" : "Instalando apps …",
     "Install recommended apps" : "Instalar las aplicaciones recomendadas",
+    "Online" : "En línea",
+    "Away" : "Ausente",
+    "Busy" : "Ocupado",
+    "Do not disturb" : "No molestar",
+    "Mute all notifications" : "Silenciar todas las notificaciones",
+    "Invisible" : "Invisible",
+    "Appear offline" : "Aparecer como desconectado",
     "Avatar of {displayName}" : "Avatar de {displayName}",
     "Settings menu" : "Menú de configuraciones",
-    "Loading your contacts …" : "Cargando tus contactos...",
-    "Looking for {term} …" : "Buscando {term}...",
+    "Loading your contacts …" : "Cargando tus contactos …",
+    "Looking for {term} …" : "Buscando {term} …",
     "Search contacts" : "Buscar contactos",
     "Reset search" : "Resetear búsqueda",
-    "Search contacts …" : "Buscar contactos...",
+    "Search contacts …" : "Buscar contactos …",
     "Could not load your contacts" : "No se han podido cargar los contactos",
     "No contacts found" : "No se han encontrado contactos",
     "Show all contacts" : "Mostrar todos los contactos",
@@ -317,7 +318,7 @@ OC.L10N.register(
     "An error occurred while searching for {type}" : "Ha ocurrido un error al buscar {type}",
     "Search starts once you start typing and results may be reached with the arrow keys" : "La búsqueda empieza una vez que comienza a escribir y los resultados pueden seleccionarse con las teclas de flecha",
     "Search for {name} only" : "Buscar solo por {name}",
-    "Loading more results …" : "Cargando más resultados …",
+    "Loading more results …" : "Cargando más resultados …",
     "Forgot password?" : "¿Contraseña olvidada?",
     "Back to login form" : "Volver al formulario de inicio de sesión",
     "Back" : "Atrás",
@@ -347,6 +348,7 @@ OC.L10N.register(
     "Storage & database" : "Almacenamiento y base de datos",
     "Data folder" : "Carpeta de datos",
     "Database configuration" : "Configuración de la base de datos",
+    "Database type" : "Tipo de base de datos",
     "Only {firstAndOnlyDatabase} is available." : "Sólo {firstAndOnlyDatabase} está disponible.",
     "Install and activate additional PHP modules to choose other database types." : "Instalar y activar módulos PHP adicionales para elegir otros formatos de base de datos.",
     "For more details check out the documentation." : "Para más detalles revisar la documentación.",
@@ -354,6 +356,7 @@ OC.L10N.register(
     "You chose SQLite as database." : "Has elegido SQLite como base de datos.",
     "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite solo debería usarse para instancias mínimas y de desarrollo. Para producción recomendamos un motor de bases de datos diferente.",
     "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Si usas clientes para sincronizar archivos, el uso del SQLite está muy desaconsejado.",
+    "Database connection" : "Conexión con base de datos",
     "Database user" : "Usuario de la base de datos",
     "Database password" : "Contraseña de la base de datos",
     "Database name" : "Nombre de la base de datos",
@@ -361,7 +364,7 @@ OC.L10N.register(
     "Please specify the port number along with the host name (e.g., localhost:5432)." : "Por favor especifique el numero del puerto junto al nombre del host (p.e., localhost:5432).",
     "Database host" : "Host de la base de datos",
     "localhost" : "localhost",
-    "Installing …" : "Instalando …",
+    "Installing …" : "Instalando …",
     "Install" : "Instalar",
     "Need help?" : "¿Necesita ayuda?",
     "See the documentation" : "Vea la documentación",
@@ -370,7 +373,7 @@ OC.L10N.register(
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Su navegador no está soportado. Por favor actualice a una versión nueva o a uno soportado.",
     "Continue with this unsupported browser" : "Continuar con este navegador no soportado",
     "Supported versions" : "Versiones soportadas",
-    "Search {types} …" : "Buscar {types}…",
+    "Search {types} …" : "Buscar {types} …",
     "Choose {file}" : "Seleccionar {file}",
     "Choose" : "Seleccionar",
     "Copy to {target}" : "Copiar a {target}",
@@ -390,7 +393,7 @@ OC.L10N.register(
     "(all selected)" : "(seleccionados todos)",
     "({count} selected)" : "({count} seleccionados)",
     "Error loading file exists template" : "Error cargando plantilla de archivo existente",
-    "Saving …" : "Guardando...",
+    "Saving …" : "Guardando …",
     "seconds ago" : "hace segundos",
     "Connection to server lost" : "Se ha perdido la conexión al servidor",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Problema al cargar la página, volverá a cargar en %n segundo","Problema al cagar la página, volverá a cargar en %n segundos","Problema al cagar la página, volverá a cargar en %n segundos"],
@@ -405,8 +408,6 @@ OC.L10N.register(
     "Type to search for existing projects" : "Escribe para buscar proyectos existentes",
     "New in" : "Nuevo en",
     "View changelog" : "Ver registro de cambios",
-    "No action available" : "No hay acciones disponibles",
-    "Error fetching contact actions" : "Error recuperando las acciones de los contactos",
     "Close \"{dialogTitle}\" dialog" : "Cerrar diálogo \"{dialogTitle}\"",
     "Email length is at max (255)" : "La longitud de correo electrónico está en su límite (255)",
     "Clipboard not available, please copy manually" : "Portapapeles no disponible, por favor copie manualmente",
@@ -494,32 +495,40 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "Está instancia %s está en modo mantenimiento, y puede tardar un rato.",
     "This page will refresh itself when the instance is available again." : "Esta página se actualizará sola cuando la instancia esté disponible de nuevo.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Contacte con su administrador de sistemas si este mensaje persiste o aparece de forma inesperada.",
-    "No temporary profile picture available, try again" : "No hay disponible una imagen temporal de perfil, pruebe de nuevo",
-    "No crop data provided" : "No se han proporcionado datos del recorte",
-    "No valid crop data provided" : "Recorte inválido",
-    "Crop is not square" : "El recorte no es cuadrado",
     "Error occurred while checking server setup" : "Ha ocurrido un error al revisar la configuración del servidor",
     "For more details see the {linkstart}documentation ↗{linkend}." : "Para más detalles compruebe la {linkstart}documentación ↗{linkend}.",
-    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Mensajes, videollamadas, compartir pantalla, reuniones online y conferencias web – en tu navegador y con apps móviles.",
-    "You have not added any info yet" : "Aún no has añadido nada de información",
-    "{user} has not added any info yet" : "{user} no ha añadido aún nada de información",
-    "Error opening the user status modal, try hard refreshing the page" : "Error al abrir la ventana de estado del usuario, intente actualizar la página",
-    "Edit Profile" : "Editar perfil",
-    "The headline and about sections will show up here" : "El título y la sección acerca de aparecerán aquí",
+    "unknown text" : "texto desconocido",
+    "Hello world!" : "¡Hola, mundo!",
+    "sunny" : "soleado",
+    "Hello {name}, the weather is {weather}" : "Hola {name}, el día es {weather}",
+    "Hello {name}" : "Hola {name}",
+    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Estos son sus resultados de búsqueda<script>alert(1)</script></strong>",
+    "new" : "Nuevo",
+    "_download %n file_::_download %n files_" : ["descargar %n archivos","descargar %n archivos","descargar %n archivos"],
+    "Direct link copied to clipboard" : "Enlace directo copiado al portapapeles",
+    "Searching …" : "Buscando  …",
+    "Logging in …" : "Iniciando sesión ...",
+    "Loading apps …" : "Cargando apps ...",
+    "Installing apps …" : "Instalando apps ...",
+    "Loading your contacts …" : "Cargando tus contactos...",
+    "Looking for {term} …" : "Buscando {term}...",
+    "Search contacts …" : "Buscar contactos...",
+    "Loading more results …" : "Cargando más resultados …",
+    "Search {types} …" : "Buscar {types}…",
+    "Saving …" : "Guardando...",
     "Very weak password" : "Contraseña muy débil",
     "Weak password" : "Contraseña débil",
     "So-so password" : "Contraseña normal",
     "Good password" : "Contraseña buena",
     "Strong password" : "Contraseña muy buena",
+    "No action available" : "No hay acciones disponibles",
+    "Error fetching contact actions" : "Error recuperando las acciones de los contactos",
     "Non-existing tag #{tag}" : "Categoría #{tag} no existente",
     "Restricted" : "Restringido",
-    "Invisible" : "Invisible",
     "Delete" : "Eliminar",
     "Rename" : "Renombrar",
     "Collaborative tags" : "Etiquetas colaborativas",
     "No tags found" : "No se encontraron etiquetas",
-    "Profile not found" : "Perfil no encontrado",
-    "The profile does not exist." : "El perfil no existe.",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Su directorio de datos y sus archivos probablemente sean accesibles a través de internet ya que el archivo .htaccess no funciona.",
     "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Para información sobre cómo configurar adecuadamente el servidor, revisa por favor la <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentación</a>.",
     "<strong>Create an admin account</strong>" : "Crear una <strong>cuenta de administrador</strong>",
@@ -530,6 +539,6 @@ OC.L10N.register(
     "Configure the database" : "Configurar la base de datos",
     "Only %s is available." : "Solo %s está disponible.",
     "Database account" : "Cuenta de la base de datos",
-    "Direct link copied to clipboard" : "Enlace directo copiado al portapapeles"
+    "Installing …" : "Instalando …"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
