@@ -18,33 +18,30 @@ OC.L10N.register(
     "Unknown filetype" : "Nezināms datnes veids",
     "An error occurred. Please contact your admin." : "Atgadījās kļūda. Lūgums sazināties ar savu pārvaldītāju.",
     "Invalid image" : "Nederīgs attēls",
-    "No temporary profile picture available, try again" : "Nav pieejams profila pagaidu attēls, jāmēģina vēlreiz",
-    "No crop data provided" : "Nav norādīti apgriešanas dati",
-    "No valid crop data provided" : "Nav norādīti derīgi apgriešanas dati",
-    "Crop is not square" : "Griezums nav kvadrāts",
     "State token does not match" : "Neatbilst stāvokļa tekstvienība",
     "Invalid app password" : "Nederīga lietotnes parole",
     "Could not complete login" : "Nevarēja pabeigt pieteikšanos",
     "State token missing" : "Trūkst stāvokļa tekstvienības",
     "Your login token is invalid or has expired" : "Pieteikšanās pilnvara nav derīga vai ir beigusies",
-    "This community release of Nextcloud is unsupported and push notifications are limited." : "Šī Nextcloud kopienas versija nav atbalstīta un push paziņojumi ir ierobežoti.",
-    "Login" : "Pieteikumvārds",
-    "Unsupported email length (>255)" : "Neatbalstāms e-pasta garums (>255)",
+    "Please use original client" : "Lūgums izmantot sākotnējo klientu",
+    "This community release of Nextcloud is unsupported and push notifications are limited." : "Šis Nextcloud kopienas laidiens nav atbalstīts un pašpiegādes paziņojumi ir ierobežoti.",
+    "Login" : "Pieteikties",
+    "Unsupported email length (>255)" : "Neatbalstīts e-pasta adreses garums (>255)",
     "Password reset is disabled" : "Paroles atiestatīšana ir atspējota",
     "Could not reset password because the token is expired" : "Nevarēja atiestatīt paroli, jo ir beidzies tekstvienības derīgums",
     "Could not reset password because the token is invalid" : "Nevarēja atiestatīt paroli, jo tekstvienība ir nederīga",
     "Password is too long. Maximum allowed length is 469 characters." : "Parole ir pārāk gara. Lielākais atļautais garums ir 469 rakstzīmes.",
-    "%s password reset" : "%s paroles maiņa",
+    "%s password reset" : "%s paroles atiestatīšana",
     "Password reset" : "Parole atiestatīta",
     "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Jānospiež zemāk esošā poga, lai atiestatītu savu paroli. Šis e-pasta ziņojums nav jāņem vērā, ja paroles atiestatīšana netika pieprasīta.",
     "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Jāklikšķina uz zemāk esošās saites, lai atiestatītu savu paroli. Šis e-pasta ziņojums nav jāņem vērā, ja paroles atiestatīšana netika pieprasīta.",
     "Reset your password" : "Atiestatīt paroli",
-    "The given provider is not available" : "Norādītājs pakalpojuma sniedzējs nav pieejams",
+    "The given provider is not available" : "Norādītais nodrošinātājs nav pieejams",
     "Task not found" : "Uzdevums nav atrasts",
     "Internal error" : "Iekšēja kļūda",
     "Not found" : "Nav atrasts",
     "Bad request" : "Slikts pieprasījums",
-    "Requested task type does not exist" : "Pieprasītā uzdevuma veids nepastāv",
+    "Requested task type does not exist" : "Pieprasītais uzdevumu veids nepastāv",
     "Image not found" : "Attēls nav atrasts",
     "No translation provider available" : "Tulkošanas pakalpojuma sniedzējs nav pieejams",
     "Could not detect language" : "Nevarēja noteikt valodu",
@@ -54,10 +51,10 @@ OC.L10N.register(
     "Repair info:" : "Labošanas informācija: ",
     "Repair warning:" : "Labošanas brīdinājums:",
     "Repair error:" : "Labošanas kļūda:",
-    "Nextcloud Server" : "Nextcloud Serveris",
+    "Nextcloud Server" : "Nextcloud serveris",
     "Some of your link shares have been removed" : "Dažas no kopīgotajām saitēm tika noņemtas",
     "Due to a security bug we had to remove some of your link shares. Please see the link for more information." : "Drošības kļūdas dēļ mums nācās noņemt dažas no kopīgotajām saitēm. Lūgums apmeklēt saiti, lai iegūtu vairāk informācijas.",
-    "The account limit of this instance is reached." : "Konta ierobežojums šajai instancei ir sasniegts.",
+    "The account limit of this instance is reached." : "Ir sasniegts konta ierobežojums šajā serverī.",
     "Learn more ↗" : "Uzzināt vairāk ↗",
     "Preparing update" : "Sagatavo atjauninājumu",
     "Please use the command line updater because updating via browser is disabled in your config.php." : "Lūgums izmantot komandrindas atjauninātāju, jo atjaunināšana pārlūkā ir atspējota config.php.",
@@ -65,34 +62,26 @@ OC.L10N.register(
     "Turned off maintenance mode" : "Izslēgts uzturēšanas režīms",
     "Maintenance mode is kept active" : "Uzturēšanas režīms ir paturēts aktīvs",
     "Updating database schema" : "Atjaunina datu bāzes shēmu",
-    "Updated database" : "Atjaunināta datu bāze",
+    "Updated database" : "Atjaunināta datubāze",
     "Update app \"%s\" from App Store" : "Atjaunināt lietotni \"%s\" no lietotņu veikala",
     "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Nosaka, vai uz %s attiecināmā shēma var tikt atjaunināta (tas var prasīt daudz laiku atkarībā no datu bāzes izmēriem)",
-    "Updated \"%1$s\" to %2$s" : "Atjaunots %1$s uz %2$s",
-    "Set log level to debug" : "Iestatīt žurnāla rakstīšanu uz atkļūdošanas režīmā",
-    "Reset log level" : "Atiestatīt žurnāla rakstīšanas režīmu",
+    "Updated \"%1$s\" to %2$s" : "\"%1$s\" atjauninnāts uz %2$s",
+    "Set log level to debug" : "Iestatīt žurnāla līmeni uz atkļūdošanu",
+    "Reset log level" : "Atiestatīt žurnāla līmeni",
     "Starting code integrity check" : "Uzsākta koda integritātes pārbaude",
     "Finished code integrity check" : "Pabeigta  koda integritātes pārbaude",
     "%s (incompatible)" : "%s (nesaderīgs)",
-    "The following apps have been disabled: %s" : "Sekojošās lietotnes tika atspējotas: %s",
+    "The following apps have been disabled: %s" : "Šīs lietotnes tika atspējotas: %s",
     "Already up to date" : "Jau ir jaunākā",
     "Unknown" : "Nezināms",
-    "Error occurred while checking server setup" : "Servera pārbaudīšanas laikā atgadījās kļūda",
-    "For more details see the {linkstart}documentation ↗{linkend}." : "Vairāk informācijas ir skatāma {linkstart}dokumentācijā ↗{linkend}.",
-    "unknown text" : "nezināms teksts",
-    "Hello world!" : "Sveika, pasaule!",
-    "sunny" : "saulains",
-    "Hello {name}, the weather is {weather}" : "Sveiciens, {name}, laikapstākļi ir {weather}",
-    "Hello {name}" : "Sveiks {name}",
-    "new" : "jauns",
-    "_download %n file_::_download %n files_" : ["lejupielādēt %n failus","lejupielādēt %n failus","lejupielādēt %n datnes"],
-    "The update is in progress, leaving this page might interrupt the process in some environments." : "Notiek atjaunināšana, šīs lapas atstāšana var pārtraukt procesu dažās vidēs.",
-    "Update to {version}" : "Atjaunināts uz {version}",
+    "LDIF address book" : "LDIF adrešu grāmata",
+    "The update is in progress, leaving this page might interrupt the process in some environments." : "Notiek atjaunināšana, šīs lapas pamešana dažās vidēs var pārtraukt to.",
+    "Update to {version}" : "Atjaunināt uz {version}",
     "An error occurred." : "Atgadījās kļūda.",
-    "Please reload the page." : "Lūdzu, atkārtoti ielādējiet lapu.",
-    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Atjauninājums nebija veiksmīgs. Vairāk informācijas par šo sarežģījumu ir skatāma <a href=\"{url}\">mūsu foruma ierakstā</a> .",
-    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Atjauninājums nebija veiksmīgs. Lūgums ziņot par šo nepilnību <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud kopienai</a>.",
-    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Atjaunināšana bija veiksmīga. Notiks pārvirzīšana uz {productName} pēc %n sekundēm.","Atjaunināšana bija veiksmīga. Notiks pārvirzīšana uz {productName} pēc %n sekundes.","Atjaunināšana bija veiksmīga. Notiks pārvirzīšana uz {productName} pēc %n sekundēm."],
+    "Please reload the page." : "Lūgums pārlādēt lapu.",
+    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Atjaunināšana bija nesekmīga. Vairāk informācijas par šo sarežģījumu ir skatāma <a href=\"{url}\">mūsu foruma ierakstā</a> .",
+    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Atjaunināšana bija nesekmība. Lūgums ziņot par šo nepilnību <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud kopienai</a>.",
+    "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Atjaunināšana bija veiksmīga. Notiks pārvirzīšana uz {productName} pēc %n sekundēm.","Atjaunināšana bija veiksmīga. Notiks pārvirzīšana uz {productName} pēc %n sekundes.","Atjaunināšana bija sekmīga. Pēc %nsekundēm notiks pārvirzīšana uz {productName}."],
     "Applications menu" : "Lietotņu izvēlne",
     "Apps" : "Lietotnes",
     "More apps" : "Vairāk lietotņu",
@@ -100,18 +89,18 @@ OC.L10N.register(
     "No" : "Nē",
     "Yes" : "Jā",
     "Failed to add the public link to your Nextcloud" : "Neizdevās pievienot publisku saiti Tavam Nextcloud",
-    "Please copy the link manually:" : "Lūdzu, nokopējiet saiti automātiski:",
-    "Pick start date" : "Izvēlieties sākuma datumu",
-    "Pick end date" : "Izvēlieties beigu datumu",
+    "Please copy the link manually:" : "Lūgums pašrocīgi ievietot saiti starpliktuvē:",
+    "Pick start date" : "Izvēlēties sākuma datumu",
+    "Pick end date" : "Izvēlēties beigu datumu",
     "Search in date range" : "Meklēt laika posmā",
     "Search in current app" : "Meklēt pašreizējā lietotnē",
     "Clear search" : "Notīrīt meklēšanu",
     "Search everywhere" : "Meklēt visur",
-    "Searching …" : "Meklē...",
     "Start typing to search" : "Sākt rakstīt, lai meklētu",
     "No matching results" : "Nav atbilstoša iznākuma",
     "Today" : "Šodien",
     "Unified search" : "Apvienotā meklēšana",
+    "Search apps, files, tags, messages" : "Meklēt lietotnes, datnes, birkas, ziņojumus",
     "Places" : "Vietas",
     "Date" : "Datums",
     "Search people" : "Meklēt cilvēkus",
@@ -120,14 +109,16 @@ OC.L10N.register(
     "Load more results" : "Ielādēt vairāk iznākumu",
     "Search in" : "Meklēt",
     "Log in" : "Pieteikties",
-    "Logging in …" : "Notiek pieteikšanās …",
-    "Log in to {productName}" : "Pierakstīties {productName}",
+    "Log in to {productName}" : "Pieteikties {productName}",
     "Wrong login or password." : "Nepareizs lietotājvārds vai parole.",
     "This account is disabled" : "Šis konts ir atspējots",
+    "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Mēs esam noteikuši vairākus nederīgus pieteikšanās mēģinājumus no šīs IP adreses, tādējādi nākamā pieteikšanās ir ierobežota līdz 30 sekundēm.",
     "Account name or email" : "Konta nosaukums vai e-pasta adrese",
     "Account name" : "Konta nosaukums",
     "Server side authentication failed!" : "Servera autentifikācija neizdevās!",
     "Please contact your administrator." : "Lūgums sazināties ar savu pārvaldītāju.",
+    "Session error" : "Sesijas kļūda",
+    "It appears your session token has expired, please refresh the page and try again." : "Izskatās, ka sesijas pilnvarai ir beidzies derīgums, lūgums atsvaidzināt lapu un mēģināt vēlreiz.",
     "An internal error occurred." : "Atgadījās iekšēja kļūda.",
     "Please try again or contact your administrator." : "Lūgums mēģināt vēlreiz vai sazināties ar savu pārvaldītāju.",
     "Password" : "Parole",
@@ -136,8 +127,8 @@ OC.L10N.register(
     "Your account is not setup for passwordless login." : "Konts nav iestatīts, lai pieteiktos bez paroles.",
     "Your connection is not secure" : "Savienojums nav drošs",
     "Passwordless authentication is only available over a secure connection." : "Autentifikācija bez paroles ir pieejama tikai ar drošu savienojumu.",
-    "Browser not supported" : "Pārlūkprogramma netiek atbalstīta",
-    "Passwordless authentication is not supported in your browser." : "Pārlūkprogrammā netiek nodrošināta autentifikācija bez paroles",
+    "Browser not supported" : "Pārlūks nav atbalstīts",
+    "Passwordless authentication is not supported in your browser." : "Pārlūks nenodrošina autentificēšanos bez paroles.",
     "Reset password" : "Atiestatīt paroli",
     "Back to login" : "Atpakaļ uz pieteikšanos",
     "Couldn't send reset email. Please contact your administrator." : "Nevarēja nosūtīt atiestatīšanas e-pasta ziņojumu. Lūgums sazināties ar savu pārvaldītāju.",
@@ -150,25 +141,22 @@ OC.L10N.register(
     "Keep your colleagues and friends in one place without leaking their private info." : "Turiet savus kolēģus un draugus vienuviet, neizpludinot viņu privāto informāciju.",
     "Simple email app nicely integrated with Files, Contacts and Calendar." : "Vienkāršā e-pasta lietotne labi apvienota ar Datnēm, Kontaktiem un Kalendāru.",
     "Recommended apps" : "Ieteiktās lietotnes",
-    "Loading apps …" : "Notiek lietotņu ielāde ...",
     "App download or installation failed" : "Lietotnes lejupielāde vai uzstādīšana neizdevās",
     "Cannot install this app" : "Nevarēja uzstādīt šo lietotni",
     "Skip" : "Izlaist",
-    "Installing apps …" : "Notiek lietotņu instalēšana ...",
+    "Busy" : "Aizņemts",
+    "Invisible" : "Neredzama",
     "Settings menu" : "Iestatījumu izvēlne",
-    "Loading your contacts …" : "Notiek kontaktpersonu ielāde...",
-    "Looking for {term} …" : "Meklē {term} …",
-    "Search contacts …" : "Meklēt kontaktpersonu",
     "Could not load your contacts" : "Nevarēja ielādēt visas kontaktpersonas",
     "No contacts found" : "Nav atrasta ne viena kontaktpersona",
-    "Install the Contacts app" : "Instalējiet lietotni Kontaktpersonas",
+    "Install the Contacts app" : "Jāuzstāda Kontaktpersonu lietotne",
     "Search" : "Meklēt",
     "Forgot password?" : "Aizmirsta parole?",
     "Back" : "Atpakaļ",
     "Security warning" : "Drošības brīdinājums",
     "Storage & database" : "Krātuve & datubāze",
     "Data folder" : "Datu mape",
-    "Install and activate additional PHP modules to choose other database types." : "Instalējiet un aktivizējiet papildus PHP moduļus lai izvēlētos citus datubāžu tipus.",
+    "Install and activate additional PHP modules to choose other database types." : "Jāuzstāda un jāaktivē papildu PHP moduļi, lai izvēlētos citus datubāžu veidus.",
     "For more details check out the documentation." : "Vairāk informācijas ir meklējama dokumentācijā.",
     "Performance warning" : "Veiktspējas brīdinājums",
     "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Ja izmanto klientus datņu sinhronizēšanai, ir ļoti ieteicams neizmantot SQLite.",
@@ -176,11 +164,11 @@ OC.L10N.register(
     "Database password" : "Datubāzes parole",
     "Database name" : "Datubāzes nosaukums",
     "Database tablespace" : "Datubāzes tabulas telpa",
-    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Lūdzu, norādiet porta numuru kopā ar resursdatora nosaukumu (piemēram, localhost: 5432).",
+    "Please specify the port number along with the host name (e.g., localhost:5432)." : "Lūgums norādītt porta numuru kopā ar resursdatora nosaukumu (piemēram, localhost:5432).",
     "Database host" : "Datubāzes serveris",
     "Need help?" : "Vajadzīga palīdzība?",
     "See the documentation" : "Skatiet dokumentāciju",
-    "Choose" : "Izvēlieties",
+    "Choose" : "Izvēlēties",
     "Copy to {target}" : "Kopēt uz {target}",
     "Copy" : "Kopēt",
     "Move to {target}" : "Pārvietot uz {target}",
@@ -198,13 +186,12 @@ OC.L10N.register(
     "(all selected)" : "(visas atlasītās)",
     "({count} selected)" : "({count} iezīmēti)",
     "Error loading file exists template" : "Kļūda esošas datnes veidnes ielādēšanā",
-    "Saving …" : "Saglabā ...",
     "seconds ago" : "pirms vairākām sekundēm",
     "Connection to server lost" : "Zaudēts savienojums ar serveri",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Problēma ielādējot lapu, pārlādēšana pēc %n sekundēm","Problēma ielādējot lapu, pārlādēšana pēc %n sekundēm","Problēma ielādējot lapu, pārlādēšana pēc %n sekundēm"],
     "Add to a project" : "Pievienot projektam",
     "Show details" : "Rādīt informāciju",
-    "Hide details" : "Slēpt detaļas",
+    "Hide details" : "Paslēpt informāciju",
     "Rename project" : "Pārdēvēt projektu",
     "Failed to rename the project" : "Neizdevās pārdēvēt projektu",
     "Failed to create a project" : "Neizdevās izveidot projektu",
@@ -212,15 +199,6 @@ OC.L10N.register(
     "Connect items to a project to make them easier to find" : "Savienojiet vienumus ar projektu, lai tos būtu vieglāk atrast",
     "New in" : "Jauns",
     "View changelog" : "Skatīt izmaiņu sarakstu",
-    "No action available" : "Nav pieejamu darbību",
-    "Error fetching contact actions" : "Kļūda rodot kontaktpersonām piemērojamās darbības",
-    "Non-existing tag #{tag}" : "Neesoša birka #{tag}",
-    "Restricted" : "Ierobežota",
-    "Invisible" : "Neredzama",
-    "Delete" : "Izdzēst",
-    "Rename" : "Pārdēvēt",
-    "Collaborative tags" : "Sadarbības birkas",
-    "No tags found" : "Netika atrasta neviena birka",
     "Personal" : "Personīgi",
     "Accounts" : "Konti",
     "Admin" : "Pārvaldītājs",
@@ -232,7 +210,7 @@ OC.L10N.register(
     "The server was unable to complete your request." : "Serveris nevarēja izpildīt tavu pieprasījumu.",
     "More details can be found in the server log." : "Vairāk informācijas var atrast servera žurnālā.",
     "For more details see the documentation ↗." : "Vairāk informācijas var atrast dokumentācijā ↗.",
-    "Technical details" : "Tehniskās detaļas",
+    "Technical details" : "Tehniskā informācija",
     "Remote Address: %s" : "Attālā adrese: %s",
     "Request ID: %s" : "Pieprasījuma ID: %s",
     "Type: %s" : "Veids: %s",
@@ -272,19 +250,42 @@ OC.L10N.register(
     "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Lai izvairītos no noildzēm lielākās instalācijās, tā vietā uzstādīšanas mapē var izpildīt šo komandu:",
     "Detailed logs" : "Detalizēti žurnāli",
     "Update needed" : "Nepieciešama atjaunināšana",
-    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Es zinu ka ja es turpināšu atjauninājumu caur tīmekļa atjauninātāju ir risks ka pieprasījumam būs noliedze , kas var radīt  datu zudumu, bet man ir dublējumkopija un es zinu kā atjaunot instanci neveiksmes gadijumā.",
+    "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Es zinu, ka, ja es turpināšu atjaunināšanu tīmekļa saskarnē, pastāv iespēja, ka pieprasījumam var iestāties noildze un var rasties datu zudums, bet man ir rezerves kopija, un es zinu kā neveiksmes gadījumā atjaunot savu serveri.",
     "Upgrade via web on my own risk" : "Atjaunināt caur tīmekļa atjauninātāju uz mana paša risku.",
     "Maintenance mode" : "Uzturēšanas režīms",
     "This %s instance is currently in maintenance mode, which may take a while." : "Šis %s serveris pašlaik darbojas uzturēšanas režīmā, tas var ilgt kādu laiku.",
     "This page will refresh itself when the instance is available again." : "Šī lapa atsvaidzināsies, kad Nextcloud būs atkal pieejams.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Jāsazinās ar sistēmas pārvaldītāju, ja šis ziņojums nepazūd vai parādījās negaidīti",
-    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Tērzēšana, videozvani, ekrāna kopīgošana, tiešsaistes sapulces un tīmekļa apspriedes - pārlūkā un viedierīču lietotnēs.",
-    "Edit Profile" : "Labot profilu",
+    "Error occurred while checking server setup" : "Servera pārbaudīšanas laikā atgadījās kļūda",
+    "For more details see the {linkstart}documentation ↗{linkend}." : "Vairāk informācijas ir skatāma {linkstart}dokumentācijā ↗{linkend}.",
+    "unknown text" : "nezināms teksts",
+    "Hello world!" : "Sveika, pasaule!",
+    "sunny" : "saulains",
+    "Hello {name}, the weather is {weather}" : "Sveiciens, {name}, laikapstākļi ir {weather}",
+    "Hello {name}" : "Sveiciens, {name}",
+    "new" : "jauns",
+    "_download %n file_::_download %n files_" : ["lejupielādēt %n datņu","lejupielādēt %n datni","lejupielādēt %n datnes"],
+    "Searching …" : "Meklē...",
+    "Logging in …" : "Notiek pieteikšanās …",
+    "Loading apps …" : "Notiek lietotņu ielāde ...",
+    "Installing apps …" : "Notiek lietotņu instalēšana ...",
+    "Loading your contacts …" : "Notiek kontaktpersonu ielāde...",
+    "Looking for {term} …" : "Meklē {term} …",
+    "Search contacts …" : "Meklēt kontaktpersonu",
+    "Saving …" : "Saglabā ...",
     "Very weak password" : "Ļoti vāja parole",
     "Weak password" : "Vāja parole",
     "So-so password" : "Viduvēja parole",
     "Good password" : "Laba parole",
     "Strong password" : "Spēcīga parole",
+    "No action available" : "Nav pieejamu darbību",
+    "Error fetching contact actions" : "Kļūda rodot kontaktpersonām piemērojamās darbības",
+    "Non-existing tag #{tag}" : "Neesoša birka #{tag}",
+    "Restricted" : "Ierobežota",
+    "Delete" : "Izdzēst",
+    "Rename" : "Pārdēvēt",
+    "Collaborative tags" : "Sadarbības birkas",
+    "No tags found" : "Netika atrasta neviena birka",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Iespējams, ka datu mape un datnes ir pieejamas no interneta, jo .htaccess datne nedarbojas.",
     "Show password" : "Rādīt paroli",
     "Toggle password visibility" : "Pārslēgt paroles redzamību",
