@@ -1,44 +1,24 @@
 <?php
-/**
- * @copyright Copyright (c) 2016, ownCloud, Inc.
- *
- * @author Morris Jobke <hey@morrisjobke.de>
- * @author Robin Appelman <robin@icewind.nl>
- * @author Thomas Müller <thomas.mueller@tmit.eu>
- * @author Robin Müller <robin.mueller@1und1.de>
- *
- * @license AGPL-3.0
- *
- * This code is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License, version 3,
- * as published by the Free Software Foundation.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License, version 3,
- * along with this program.  If not, see <http://www.gnu.org/licenses/>
- *
- */
 
+/**
+ * SPDX-FileCopyrightText: 2016-2024 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-FileCopyrightText: 2016 ownCloud, Inc.
+ * SPDX-License-Identifier: AGPL-3.0-only
+ */
 namespace OC\Repair;
 
 use Doctrine\DBAL\Exception\DriverException;
-use Doctrine\DBAL\Platforms\MySqlPlatform;
 use OCP\IConfig;
 use OCP\IDBConnection;
-use OCP\ILogger;
 use OCP\Migration\IOutput;
 use OCP\Migration\IRepairStep;
+use Psr\Log\LoggerInterface;
 
 class Collation implements IRepairStep {
-	/**  @var IConfig */
+	/** @var IConfig */
 	protected $config;
 
-	/** @var ILogger */
-	protected $logger;
+	protected LoggerInterface $logger;
 
 	/** @var IDBConnection */
 	protected $connection;
@@ -47,12 +27,14 @@ class Collation implements IRepairStep {
 	protected $ignoreFailures;
 
 	/**
-	 * @param IConfig $config
-	 * @param ILogger $logger
-	 * @param IDBConnection $connection
 	 * @param bool $ignoreFailures
 	 */
-	public function __construct(IConfig $config, ILogger $logger, IDBConnection $connection, $ignoreFailures) {
+	public function __construct(
+		IConfig $config,
+		LoggerInterface $logger,
+		IDBConnection $connection,
+		$ignoreFailures,
+	) {
 		$this->connection = $connection;
 		$this->config = $config;
 		$this->logger = $logger;
@@ -67,12 +49,12 @@ class Collation implements IRepairStep {
 	 * Fix mime types
 	 */
 	public function run(IOutput $output) {
-		if (!$this->connection->getDatabasePlatform() instanceof MySqlPlatform) {
+		if ($this->connection->getDatabaseProvider() !== IDBConnection::PLATFORM_MYSQL) {
 			$output->info('Not a mysql database -> nothing to do');
 			return;
 		}
 
-		$characterSet = $this->config->getSystemValue('mysql.utf8mb4', false) ? 'utf8mb4' : 'utf8';
+		$characterSet = $this->config->getSystemValueBool('mysql.utf8mb4', false) ? 'utf8mb4' : 'utf8';
 
 		$tables = $this->getAllNonUTF8BinTables($this->connection);
 		foreach ($tables as $table) {
@@ -82,24 +64,19 @@ class Collation implements IRepairStep {
 				$query->execute();
 			} catch (DriverException $e) {
 				// Just log this
-				$this->logger->logException($e);
+				$this->logger->error($e->getMessage(), ['exception' => $e]);
 				if (!$this->ignoreFailures) {
 					throw $e;
 				}
 			}
 
 			$output->info("Change collation for $table ...");
-			if ($characterSet === 'utf8mb4') {
-				// need to set row compression first
-				$query = $this->connection->prepare('ALTER TABLE `' . $table . '` ROW_FORMAT=COMPRESSED;');
-				$query->execute();
-			}
 			$query = $this->connection->prepare('ALTER TABLE `' . $table . '` CONVERT TO CHARACTER SET ' . $characterSet . ' COLLATE ' . $characterSet . '_bin;');
 			try {
 				$query->execute();
 			} catch (DriverException $e) {
 				// Just log this
-				$this->logger->logException($e);
+				$this->logger->error($e->getMessage(), ['exception' => $e]);
 				if (!$this->ignoreFailures) {
 					throw $e;
 				}
@@ -115,17 +92,17 @@ class Collation implements IRepairStep {
 	 * @return string[]
 	 */
 	protected function getAllNonUTF8BinTables(IDBConnection $connection) {
-		$dbName = $this->config->getSystemValue("dbname");
-		$characterSet = $this->config->getSystemValue('mysql.utf8mb4', false) ? 'utf8mb4' : 'utf8';
+		$dbName = $this->config->getSystemValueString('dbname');
+		$characterSet = $this->config->getSystemValueBool('mysql.utf8mb4', false) ? 'utf8mb4' : 'utf8';
 
 		// fetch tables by columns
 		$statement = $connection->executeQuery(
-			"SELECT DISTINCT(TABLE_NAME) AS `table`" .
-			"	FROM INFORMATION_SCHEMA . COLUMNS" .
-			"	WHERE TABLE_SCHEMA = ?" .
-			"	AND (COLLATION_NAME <> '" . $characterSet . "_bin' OR CHARACTER_SET_NAME <> '" . $characterSet . "')" .
-			"	AND TABLE_NAME LIKE '*PREFIX*%'",
-			array($dbName)
+			'SELECT DISTINCT(TABLE_NAME) AS `table`'
+			. '	FROM INFORMATION_SCHEMA . COLUMNS'
+			. '	WHERE TABLE_SCHEMA = ?'
+			. "	AND (COLLATION_NAME <> '" . $characterSet . "_bin' OR CHARACTER_SET_NAME <> '" . $characterSet . "')"
+			. "	AND TABLE_NAME LIKE '*PREFIX*%'",
+			[$dbName]
 		);
 		$rows = $statement->fetchAll();
 		$result = [];
@@ -135,11 +112,11 @@ class Collation implements IRepairStep {
 
 		// fetch tables by collation
 		$statement = $connection->executeQuery(
-			"SELECT DISTINCT(TABLE_NAME) AS `table`" .
-			"	FROM INFORMATION_SCHEMA . TABLES" .
-			"	WHERE TABLE_SCHEMA = ?" .
-			"	AND TABLE_COLLATION <> '" . $characterSet . "_bin'" .
-			"	AND TABLE_NAME LIKE '*PREFIX*%'",
+			'SELECT DISTINCT(TABLE_NAME) AS `table`'
+			. '	FROM INFORMATION_SCHEMA . TABLES'
+			. '	WHERE TABLE_SCHEMA = ?'
+			. "	AND TABLE_COLLATION <> '" . $characterSet . "_bin'"
+			. "	AND TABLE_NAME LIKE '*PREFIX*%'",
 			[$dbName]
 		);
 		$rows = $statement->fetchAll();
@@ -150,4 +127,3 @@ class Collation implements IRepairStep {
 		return array_keys($result);
 	}
 }
-
